@@ -82,11 +82,17 @@ void terminal_window_update_geometry  (TerminalWindow *window);
 void terminal_window_set_size         (TerminalWindow *window,
                                        TerminalScreen *screen,
                                        gboolean        even_if_mapped);
+void terminal_window_set_size_force_grid (TerminalWindow *window,
+                                          TerminalScreen *screen,
+                                          gboolean        even_if_mapped,
+                                          int             force_grid_width,
+                                          int             force_grid_height);
 
 void     terminal_window_set_fullscreen (TerminalWindow *window,
                                          gboolean        setting);
 gboolean terminal_window_get_fullscreen (TerminalWindow *window);
 
+void terminal_window_reread_profile_list (TerminalWindow *window);
 
 G_END_DECLS
 
